Testing `porchlight`
--------------------

To run the following tests, ensure you are in the root porchlight directory
above this one (`../..` from the dir containing this file) and run the command:
`python -m unittest`.
